@@ -65,31 +65,63 @@ test_that("optim_model_space_params correctly computes small_economic_growth_ms"
   compare_matrices(params, small_model_space$params, tols = rep(0.001, 8))
 })
 
+non_zero_stats_mask_generator <- function(lin_features_n) {
+  ones <- rep(1, lin_features_n)
+  lin_features_mask <- t(rje::powerSetMat(lin_features_n))
+  mask_where_nonzero <- rbind(
+    ones, ones, ones,
+    lin_features_mask,
+    ones,
+    lin_features_mask
+  )
+  zeros <- rep(0, lin_features_n)
+  mask_where_greater_than_zero <- rbind(
+    zeros, zeros, zeros,
+    lin_features_mask,
+    zeros,
+    lin_features_mask
+  )
+  list(
+    nonzero = mask_where_nonzero,
+    greater_than_zero = mask_where_greater_than_zero
+  )
+}
 
-test_that(paste("compute_model_space_stats computes correct likelihoods and",
-                "standard deviations based on small_model_space"), {
-                  set.seed(23)
+test_that(
+  paste(
+    "compute_model_space_stats computes correct likelihoods and standard",
+    "deviations based on small_model_space"
+    ),
+  {
+    set.seed(23)
 
-                  data_prepared <- bdsm::economic_growth[, 1:6] %>%
-                    bdsm::feature_standardization(
-                      excluded_cols = c(country, year, gdp)
-                    ) %>%
-                    bdsm::feature_standardization(
-                      group_by_col  = year,
-                      excluded_cols = country,
-                      scale         = FALSE
-                    )
+    lin_features_n <- 3
 
-                  model_space_stats <- compute_model_space_stats(
-                    df            = data_prepared,
-                    dep_var_col   = gdp,
-                    timestamp_col = year,
-                    entity_col    = country,
-                    params        = small_model_space$params
-                  )
+    data_prepared <- bdsm::economic_growth[, 1:(3+lin_features_n)] %>%
+      bdsm::feature_standardization(
+        excluded_cols = c(country, year, gdp)
+      ) %>%
+      bdsm::feature_standardization(
+        group_by_col  = year,
+        excluded_cols = country,
+        scale         = FALSE
+      )
 
-                  expect_equal(model_space_stats, small_model_space$stats)
-                })
+    model_space_stats <- compute_model_space_stats(
+      df            = data_prepared,
+      dep_var_col   = gdp,
+      timestamp_col = year,
+      entity_col    = country,
+      params        = small_model_space$params
+    )
+
+    masks <- non_zero_stats_mask_generator(lin_features_n)
+
+    expect_equal(model_space_stats, small_model_space$stats)
+    expect_true(all(model_space_stats[masks$non_zero == 1] != 0))
+    expect_true(all(model_space_stats[masks$greater_than_zero == 1] > 0))
+  }
+)
 
 
 test_that(paste("model_space computes correct model_space list"), {
@@ -157,15 +189,16 @@ test_that("Moral-Benito BMA results are replicated (main branch only)", {
   actual <- bma_results[[1]]
   expected <- bdsm::full_bma_results[[1]]
 
-  if (as.character(getRversion()) != "4.4.2") {
-    # define per-column tolerances
-    tols <- rep(0.003, ncol(expected))
-    tols[4] <- 0.005
-    tols[7] <- 0.006
-    tols[ncol(expected)] <- 0.8
-  } else{
-    tols <- NULL
-  }
+  # define per-column tolerances
+  tols <- rep(0.003, ncol(expected))
+  tols[4] <- 0.005
+  tols[7] <- 0.006
+  tols[ncol(expected)] <- 0.8
+
+  lin_features_n <- 9
+  masks <- non_zero_stats_mask_generator(lin_features_n)
 
   compare_matrices(actual, expected, tols = tols)
+  expect_true(all(model_space$stats[masks$non_zero == 1] != 0))
+  expect_true(all(model_space$stats[masks$greater_than_zero == 1] > 0))
 })
